/*
 * Copyright (c) 2015 Samsung Electronics Co., Ltd. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

(function() {
    /**
     * Handles the hardware key events.
     * @private
     * @param {Object} event - The object contains data of key event
     */
    function keyEventHandler(event) {
        if (event.keyName === "back") {
            try {
                tizen.application.getCurrentApplication().exit();
            } catch (ignore) {}
        }
    }

    /**
     * Show the getUserMedia video stream from the camera in the video object.
     * @private
     * @param {Object} stream - A MediaStream object that contains the media stream from the camera.
     */
    function showStream(stream) {
        var objVideo = document.querySelector("#video-mirror");

        objVideo.srcObject = stream;
        objVideo.play();
    }

    /**
     * Sets the default style of elements.
     * @private
     */
    function setDefaultViews() {
        var defaultErrorMessage = document.querySelector("#error-message");

        defaultErrorMessage.style.display = "none";
    }

    /**
     * Sets the default value to the variables and application environment.
     * @private
     */
    function setDefaultVariables() {
        navigator.getUserMedia = navigator.getUserMedia || navigator.webkitGetUserMedia;
        if (!navigator.getUserMedia) {
            return false;
        }

        return true;
    }

    /**
     * Sets the default position and style of elements.
     * @private
     */
    function setDefaultEvents() {
        document.addEventListener("tizenhwkey", keyEventHandler);

        if (navigator.getUserMedia) {
            try {
                navigator.getUserMedia({
                        video: true
                    },
                    showStream,
                    function(err) {
                        console.log(err);
                    }
                );
            } catch (ignore) {
                return false;
            }
        } else {
            return false;
        }

        return true;
    }

    /**
     * Initializes the application.
     * @private
     */
    function init() {
        if (setDefaultVariables() && setDefaultEvents()) {
            setDefaultViews();
            console.log("App: init");
        } else {
            console.error("App: init: Error");

            tizen.application.getCurrentApplication().exit();
        }
    }

    window.onload = init;
}());